# vim: set sw=4 ts=4 et:

# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/

Name:           gnunet
Version:        0.9.2
Release:        1.3
Summary:        Security focused Peer-to-Peer Framework
Source:         ftp://ftp.gnu.org/gnu/gnunet/gnunet-%{version}.tar.gz
Source1:        gnunet.init
Patch1:         gnunet-fix_postgresql_include.patch
Patch2:         gnunet-etc_for_config.patch
URL:            http://gnunet.org
Group:          Productivity/Networking/Other
License:        GNU General Public License version 2 or later (GPL v2 or later)
BuildRoot:      %{_tmppath}/build-%{name}-%{version}
BuildRequires:  gtk2-devel libqt4-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libcurl-devel
BuildRequires:  libxml2-devel
BuildRequires:  libextractor-devel
BuildRequires:  gmp-devel
BuildRequires:  libqt4-devel
BuildRequires:  libesmtp-devel
BuildRequires:  libmicrohttpd-devel
BuildRequires:  sqlite3-devel
BuildRequires:  guile-devel
BuildRequires:  libcares-devel
BuildRequires:  libadns-devel
BuildRequires:  postgresql-devel
BuildRequires:  libmysqlclient-devel
BuildRequires:  libunistring-devel
BuildRequires:  glpk-devel
BuildRequires:  gcc make glibc-devel
BuildRequires:  autoconf automake libtool
Provides:       gnunetd = %{version}-%{release}
Provides:       GNUnet = %{version}-%{release}
Provides:       GNUnetd = %{version}-%{release}

%description
GNUnet is peer-to-peer framework focusing on security. The first and primary
application for GNUnet is anonymous file-sharing. GNUnet is currently developed
by a worldwide group of independent free software developers.

GNUnet is a part of the GNU project (http://www.gnu.org/).

%package devel
Summary:        Security focused Peer-to-Peer Framework
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}-%{release}

%description devel
GNUnet is peer-to-peer framework focusing on security. The first and primary
application for GNUnet is anonymous file-sharing. GNUnet is currently developed
by a worldwide group of independent free software developers.

%package mysql
Summary:        MySQL Storage Backend for %{name}
Group:          Productivity/Networking/Other
Requires:       %{name} = %{version}

%description mysql
GNUnet is peer-to-peer framework focusing on security. The first and primary
application for GNUnet is anonymous file-sharing. GNUnet is currently developed
by a worldwide group of independent free software developers.

%package postgresql
Summary:        PostgreSQL Storage Backend for %{name}
Group:          Productivity/Networking/Other
Requires:       %{name} = %{version}

%description postgresql
GNUnet is peer-to-peer framework focusing on security. The first and primary
application for GNUnet is anonymous file-sharing. GNUnet is currently developed
by a worldwide group of independent free software developers.

%prep
%setup -q
%patch1
%patch2

%build
autoreconf -fiv

%configure \
    --with-daemon-home-dir="%{_var}/lib/gnunet" \
    --with-daemon-config-dir="%{_sysconfdir}"

%__make %{?_smp_mflags} V=1 \
    pkgcfgdir="%{_sysconfdir}/gnunet"

%install
%makeinstall \
    pkgcfgdir="%{_sysconfdir}/gnunet"

%__rm "%{buildroot}%{_libdir}"/*.la
%__rm -rf "%{buildroot}%{_datadir}/doc"

DEVEL="$PWD/%{name}.devel.lst"
MODS="$PWD/%{name}.modules.lst"
echo -n > "$MODS"
echo -n > "$DEVEL"

for m in \
arm core-list-connections \
daemon-{exit,hostlist,topology,pt} \
dht-{get,put} \
directory download download-manager.scm fs \
helper-{dns,exit,fs-publish,nat-{client,server},transport-wlan,vpn} \
nat-server peerinfo pseudonym publish resolver search \
service-{arm,ats,core,datastore,dht,dns,fs,mesh,namestore,nse,peerinfo,resolver,statistics,template,transport,vpn} \
statistics template \
transport transport-certificate-creation testing \
unindex \
vpn \
; do
    echo "%attr(0755,root,root) %{_bindir}/gnunet-${m}" >> "$MODS"
done

for m in \
block_dht block_dns block_fs block_template block_test \
datacache_sqlite datacache_template \
datastore_sqlite datastore_template \
namestore_sqlite \
test \
transport_{http,https,tcp,template,udp,unix,wlan} \
; do
    echo "%{_libdir}/gnunet/libgnunet_plugin_${m}.so" >> "$MODS"
    echo "%{_libdir}/gnunet/libgnunet_plugin_${m}.la" >> "$MODS"
done

for m in \
arm ats block core \
datacache datastore \
dht dns dnsparser fragmentation \
fs hello mesh namestore nat nse \
peerinfo statistics testing \
transport transporttesting tun \
util \
vpn \
; do
    case $m in
        arm|datastore)
            soname=1
            ;;
        fs)
            soname=2
            ;;
        util)
            soname=7
            ;;
        *)
            soname=0
            ;;
    esac
    echo "%{_libdir}/libgnunet${m}.so.${soname}" >> "$MODS"
    echo "%{_libdir}/libgnunet${m}.so.${soname}.*" >> "$MODS"
    echo "%{_libdir}/libgnunet${m}.so" >> "$DEVEL"
    case $m in
        ats|dns|dnsparser|mesh|namestore|transporttesting|tun|vpn) ;;
        *) echo "%{_libdir}/pkgconfig/gnunet${m}.pc" >> "$DEVEL"
    esac
done

for m in \
dhtlog dv \
; do
    echo "%{_libdir}/pkgconfig/gnunet${m}.pc" >> "$DEVEL"
done

cat "$MODS" > rpmfiles.lst
cat "$DEVEL" > rpmdevfiles.lst

# install init script
%__install -D -m0755 "%{SOURCE1}" "%{buildroot}/etc/init.d/%{name}"
%__install -d "%{buildroot}/usr/sbin"
%__ln_s "../../etc/init.d/%{name}" "%{buildroot}/usr/sbin/rc%{name}"

%__install -d "%{buildroot}/var/lib/gnunet"

cat<<EOF > "%{buildroot}%{_sysconfdir}/gnunet.conf"
[PATHS]
SERVICEHOME = %{_var}/lib/gnunet
DEFAULTCONFIG = %{_sysconfdir}/gnunet.conf
EOF

%find_lang gnunet

%pre
/usr/sbin/groupadd -r gnunet || :
/usr/sbin/useradd -r -g gnunet -c "GNUnet daemon" -d /var/lib/gnunet gnunet || :

%post -p /sbin/ldconfig

%preun
%stop_on_removal %{name}

%postun
/sbin/ldconfig
%restart_on_update %{name}
%insserv_cleanup

%clean
%{?buildroot:%__rm -rf "%{buildroot}"}

%files -f gnunet.lang -f rpmfiles.lst
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/gnunet.conf
%dir %{_sysconfdir}/gnunet
%config %{_sysconfdir}/gnunet/*.conf
/etc/init.d/gnunet
/usr/sbin/rcgnunet
%dir %{_libdir}/gnunet
%{_var}/lib/gnunet
%{_bindir}/mockup-service
%dir %{_datadir}/gnunet
%{_datadir}/gnunet/gnunet-logo-color.png
%doc %{_mandir}/man1/gnunet-*.1*

%files mysql
%defattr(-,root,root)
%{_libdir}/gnunet/libgnunet_plugin_datacache_mysql.so
%{_libdir}/gnunet/libgnunet_plugin_datacache_mysql.la
%{_libdir}/gnunet/libgnunet_plugin_datastore_mysql.so
%{_libdir}/gnunet/libgnunet_plugin_datastore_mysql.la

%files postgresql
%defattr(-,root,root)
%{_libdir}/gnunet/libgnunet_plugin_datacache_postgres.so
%{_libdir}/gnunet/libgnunet_plugin_datacache_postgres.la
%{_libdir}/gnunet/libgnunet_plugin_datastore_postgres.so
%{_libdir}/gnunet/libgnunet_plugin_datastore_postgres.la

%files devel -f rpmdevfiles.lst
%defattr(-,root,root)
%{_includedir}/gnunet

%changelog
* Thu Mar  1 2012 pascal.bleser@opensuse.org
- update to 0.9.2: too many changes to list, details are in ChangeLog
* Thu Dec  1 2011 pascal.bleser@opensuse.org
- update to 0.9.0:
  * major change of the architecture and a rewrite of most of the system
  * improvements:
  - a new multi-process architecture
  - a new VPN subsystem, a new setup tool (including automated correctness tests for the configuration), support for non-anonymous mesh routing, data transport over HTTPS and WLAN, peer discovery in the LAN via broadcast (IPv4) and multicast (IPv6), improved connectivity via NAT traversal, an event-driven execution model providing significant performance improvements, and power publishing for file sharing to improve content replication.
* Tue Mar  1 2011 pascal.bleser@opensuse.org
- 0.8.1b, moved to new packman infrastructure
